DiscreteDomain
==============

.. currentmodule:: pqp.data

.. autoclass:: DiscreteDomain
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DiscreteDomain.get_values

   .. rubric:: Methods Documentation

   .. automethod:: get_values
